# What is Phaser? [en](./README.md)
Phaser는 HTML을 기반으로한 데스크탑과 모바일용 게임 프레임워크입니다.
Phaser는 JavaScript 혹은 TypeScript 기반에서 사용될 수 있습니다.
Phaser는 canvas와 WebGL을 통해 렌더링을 진행하므로, 데스크탑과 모바일 모두에서 사용할 수 있습니다.
하지만, 웹 브라우저를 사용하지 않고 모바일 환경에서 Phaser 게임을 실행시키고 싶으시다면 3rd party app을 찾아봐야 합니다.
 <br/><br/>
보다 많고 자세한 내용을 확인하고 싶으시다면 아래 문서를 참조해주세요.
 <br/>
 <strong>Phaser Website</strong>: https://phaser.io <br/>
 <strong>Phaser API docs</strong>: https://photonstorm.github.io/phaser3-docs/index.html <br/>
 <strong>Phaser Examples</strong>: https://phaser.io/examples <br/>
<br/>
# Why Phaser?
아마, 왜 **Unity**나 **Unreal**이 아닌 Phaser를 사용하는지 의문이 있으실 겁니다. 여러 가지 이유가 있지만, 다음 이유가 대표적인 예시입니다.<br/>
* Phaser를 활용하여 데스크탑과 모바일 모두에서 돌아가는 게임을 만들 수 있습니다. (모바일용과 데스크탑용 두 개를 분리할 필요가 없습니다)<br/>
* 오픈소스 프레임워크이므로 자유롭게 사용할 수 있으며, [**Phaser GitHub**](https://github.com/photonstorm/phaser)에서 Phaser의 발전에 기여할 수 있습니다.
* 3rd party app이나 다른 프레임워크를 사용하지 않는다면, 크롬이나 사파리 같은 웹 브라우저만으로 Phaser 게임을 실핼할 수 있습니다.
# Phaser를 사용하기 위해 어떤 준비를 해야하나요?
## Phaser를 준비하기 이전에
Phaser의 사용을 준비하기 이전에 보안 문제, CORS 제약 등의 문제 떄문에 로컬 웹서버를 준비하실 필요가 있습니다. 이에 대해서는 원하시는 로컬 웹서버를 준비하시면 됩니다.
## 환경 설정 이후
script에 CDN을 추가하거나 NPM을 통해 설치하실 수 있습니다. 혹은 GitHub이나 Phaser 아카이브에서 직접 다운 받으실 수 있습니다. 아래는 Phaser 아카이브 링크이며, 원하는 버전으로 다운 받으실 수 있습니다. 필요한 파일들을 NPM이나 GitHub 혹은 아카이브를 통해 다운 받으셨다면 이제 Phaser를 사용할 준비가 되셨습니다! (물론, CDN을 활용하실 수도 있습니다.)
<br/><br/>
<strong>Phaser Archive</strong>: https://phaser.io/download/archive <br/>
<br/>
**Using CDN**
<pre><code>&#60;script src="//cdn.jsdelivr.net/npm/phaser@3.51.0/dist/phaser.js"&#62;&#60;/script&#62;
</code></pre><br/>

# Phaser 게임의 기본 구조
아래는 HTML, Script 그리고 CDN을 활용한 기초적인 구조입니다. 만약, 아래 예시에서 사용하는 코드의 의미나 내용이 궁금하시다면, 문서 하단의 추가 주제 내용을 확인해주세요.
<pre><code>
&#60;!DOCTYPE html&#62;
&#60;html&#62;

&#60;head&#62;
    &#60;script src="//cdn.jsdelivr.net/npm/phaser@3.51.0/dist/phaser.js"&#62;&#60;/script&#62;
&#60;/head&#62;

&#60;body&#62;

    &#60;script&#62;
        var config = {
            type: Phaser.AUTO,
            width: 800, // 캔버스 너비를 지정합니다.
            height: 600, // 캔버스 높이를 지정합니다.
            physics: {
            default: 'arcade',  //  arcade, matter impact 중에서 어떤 물리 엔진을 사용할지 지정합니다.
            arcade: {
                gravity: { y: 100 } // 물리 엔진 설정값입니다.
            }
            },
            scene: {
            preload: preload,
            create: create
            }
        };

        var game = new Phaser.Game(config);

        function preload (){

        }

        function create (){

        }

    &#60;/script&#62;

&#60;/body&#62;

&#60;/html&#62;



</code></pre><br/>

# 어떻게 Phaser 게임을 만드나요?
2D 횡스크롤 게임, 퍼즐 게임 등등 다양한 게임들을 만들 수 있습니다. 시작하는 단계로써, 다음 예시들을 참조하면 도움이 될 것입니다. [Phaser website game examples](https://phaser.io/examples/v3/category/games)
<br/><br/>
# Phaser 3에 대한 추가 주제
Phaser 게임 개발에 도움이 될 수 있는 여러 가지 특징, 차이 및 주제에 대해서 얘기하고자 합니다. 아래는 그 내용입니다.
<br/>
[<strong>Phaser Scene cycle</strong>](./lifecycle/README_kr.md)<br/>
[<strong>Phaser Physics: arcade & matter</strong>](./physics/README_kr.md)
<br><br><br>
### 주의사항
본 프로젝트는 Phaser 3.24.1를 기반으로 제작하였습니다.<br>
문서들은 변화의 여지가 없을만한 Phaser 3의 기본적인 부분을 다루고자 하였습니다. 하지만 최신 버전과 큰 차이가 있다고 느껴지실 경우, 알려주시면 감사하겠습니다.

<br><br><br><br>
<img src="./by.png" alt="CC_BY" width="150"/>