# Phaser 3 Life cycle [ko](./README_kr.md)
Phaser's Scene consists of 3 main states which are **CREATE**, **UPDATE** and **STOP**. You can switch to each state using triggering events on manually and also you can add eventhandler for those. Please check flow chart on <strong>[Phaser 3 Scene Note](https://rexrainbow.github.io/phaser3-rex-notes/docs/site/scene/)</strong> to see how phaser's states are enterd and what detailed steps are.<br/><br/>
However, if you just started using phaser, you should know 3 basic Scene functions **preload**, **create** and **update**.
<pre><code>   
    preload (){
        // Codes in here will be executed before create()
    }

    create (){
       // Codes in here will be executed before Scene starts updating
    }

    update(){
        // Codes in here will be executed every time Phaser update this scene
    }

</code></pre><br/>
![phaser 3 scene basic cycle](./phaser_3_scene_basic_cycle.PNG)

Usually, you can load images or other resources at **preload** and create Phaser objects at **create** like sprite objects or others. And make your own game logic at **update**(If you are going to make event listner for logic, never write those codes in **update**). But you have to consider that **update** get executed periodically which is related with FPS. 

---
## Why should we load resources at **preload** and make objects at **create**?
You may wonder why i suggest you to load resources at **preload** and create objects at **create**. Well, if you try you may see that some objects not being created well especially image related objects. This is because Phaser is based on JavaScript which makes loading resources asynchronously. Thus, to avoid such problem, i recommend you to load resources at preload and create phaser object after **preload** but it is not mandatory nor official.

 ---
## How can i change update rate?
You may want to limi your update rate because of performance issue or other reason. And you can limit them since start by setting **config** for physics or using **physics.world.setFPS()** but it sometimes doesn't work depends on your Phaser version. Then, how should you do to do so? You can limit update rate by skipping some of update execution. Below is example
<pre><code>
    function update(){
        this.c += 1;
        if(this.c > 1){
            this.c = 0;
            return;
        }
        ...
    }

</code></pre>
Above code would let Phaser run **update** as half of default rate whcih means, if your Phaser game execute **update** 60 times a second, then above code block will make it 30 time a second. But you can't increase it.

---
## Isn't there any **finish** in cycle?
Of course, there is state of Phaser Scene in **STOP** state which stands for when Phaser Scene is 'destroyed'(or you may say it as 'finished'). This state can be entered by triggering **destroy** event. However, as you see, there are **preload**, **create** and **update** but not others like **finish** or **destroy** from above. But you can add eventlistner to **destroy** event so you can unleash memories or do other stuffs.

<br><br>

---
[back to main](../README.md)

<br><br><br><br>
<img src="../by.png" alt="CC_BY" width="150"/>