# Phaser 3 Life cycle [en](./README.md)
Phaser의 Scene은 크게 다음의 세 가지 상태로 이루어져 있습니다. **CREATE**, **UPDATE** 그리고 **STOP**입니다. 이벤트를 수동으로 발생시켜서 상태를 전환할 수도 있으며, 이벤트 리스너를 추가할 수도 있습니다. 자세한 상태 간의 전환 방식이나 보다 세부적인 상태를 확인하고 싶으시다면, <strong>[Phaser 3 Scene Note](https://rexrainbow.github.io/phaser3-rex-notes/docs/site/scene/)</strong>의 flow chart를 참고해주세요.<br/><br/>
하지만, 여러분이 이제 막 Phaser를 이용한 개발을 시작하셨다면 모든 세부 상태와 스탭을 알 필요는 없습니다. Phaser 게임 개발을 하기 위해서는  **preload**, **create** 그리고 **update**만 숙지해도 충분합니다.
<pre><code>   
    preload (){
        // 이곳에 있는 코드는 게임이 실행되어 create 단계에 들어가기 전에 실행됩니다.
    }

    create (){
       // 이곳에 있는 코드는 preload가 실행된 이후, update가 최초로 시작되기 전에 실행됩니다.
    }

    update(){
        // 이곳에 있는 코드는 게임이 돌아가는 도중에 계속해서 실행됩니다.
    }

</code></pre><br/>
![phaser 3 scene basic cycle](./phaser_3_scene_basic_cycle.PNG)

보통은 **preload** 에서 이미지 등의 리소스들을 불러와 저장해두며,  **create** 에서 스프라이트 오브젝트를 비롯한 각종 게임 오브젝트를 생성합니다. 그리고 **update**에서 게임 로직을 구현하여, 게임이 로직에 맞게 돌아가도록 합니다(이벤트 리스너 등을 이용할 경우 **update**에서 작성하면 안 됩니다!). 하지만 **update** 는 주기적으로 실행되며, 이는 FPS와도 연관이 있음을 알고게셔야 합니다.

---
## 왜 **preload**에서 리소스를 불러오고 **create**에서 게임 오브젝트를 생성하나요??
왜 제가 위에서 **preload**에서 리소스를 불러오고 **create**에서 게임 오브젝트를 생성하는지 궁금하실 수도 있습니다. 만약 Preload에서 특히 이미지와 관련된 게임 오브젝트인 Sprite나 다른 오브젝트를 생성해보면 문제가 발생하는 것을 보실 수 있을 것입니다. 이는, Phaser가 JavaScript를 기반으로 하고 있는데, 이 떄문에 리소스를 비동기적으로 불러오기 때문입니다. 그렇기에, 이러한 비동기적 실행으로 인한 문제를 방지하고자 **preload** 이후에 게임 오브젝트 생성을 추천드렸습니다 하지만 이는 필수가 아니며, 공식적인 내용은 아닐수 있습니다.

 ---
## update의 주기를 바꿀 수는 없나요?
성능상의 문제나 혹은 다른 이유로 **update**의 실행 주기를 바꾸고 싶으실 수 있습니다. physics의 **config**를 통해서 초당 실행 횟수를 제한하거나  **physics.world.setFPS()** 함수를 이용하여 제한할수도 있지만, Phaser의 버전에 따라서 작동하지 않을 수 있습니다. 그런 경우에는 어떻게 할까요? update 실행을 일부 건너뜀으로써 이를 구현할 수 있습니다. 아래는 예시입니다.
<pre><code>
    function update(){
        this.c += 1;
        if(this.c > 1){
            this.c = 0;
            return;
        }
        ...
    }

</code></pre>
위의 코드는 **update**가 기존 실행 횟수의 절반으로 실행 횟수를 줄입니다. 예를 들어, 기존의 Phaser 게임에서 **update**를 초당 60회 실행 하였었다면, 위의 코드를 통해 초당 30회로 줄일 수 있습니다. 하지만 이를 증가시킬 수는 없습니다.

---
## 순환 주기에서 **종료**는 없나요?
물론, Phaser Scene의 '제거'(혹은 '종료'라고 간주하여도 무방합니다)에  해당하는 상태가 **STOP**의 범주 안에 속해있습니다. 이 상태는 **destroy** 이벤트를 통해서 진입할 수 있습니다. 그러나, 위에서는 보시다시피 **preload**, **created** 그리고 **update**만 있습니다. 하지만, 이벤트 리스너를 통해서 **destory** 이벤트 발생 시 실행될 코드를 작성할 수 있으며, 이때 메모리의 관리를 해주거나 다른 작업을 하실 수 있습니다.

<br><br>

---
[메인으로](../README_kr.md)

<br><br><br><br>
<img src="../by.png" alt="CC_BY" width="150"/>